==> tinyarray_2.2.6.tar.gz: tinyarray/R/data.R <==
#' cod
#'
#' An expression matrix form TCGA
#'
#' @examples
#'   cod
"cod"

#' deg
#'
#' limma differential analysis result for GSE42872
#'
#' @examples
#'   head(deg)
"deg"

#' deseq_data
#'
#' DEseq2 differential analysis result
#'
#' @examples
#'   head(deseq_data)
"deseq_data"

#' exists_anno_list
#'
#' AnnoProbe supported  GPLs
#'
#' @examples
#'   exists_anno_list
"exists_anno_list"

#' exp_hub1
#'
#' An expression matrix from TCGA
#'
#' @examples
#'   exp_hub1[1:4,1:4]
"exp_hub1"


#' exprSet_hub1
#'
#' An expression matrix from TCGA,tumor samples only
#'
#' @examples
#'   exprSet_hub1[1:4,1:4]
"exprSet_hub1"


#' genes
#'
#' some gene entriz ids
#'
#' @examples
#'   genes
"genes"

#' lnc_anno
#'
#' annotation for TCGA expression matrix(lncRNA),form genecode v22 gtf file.
#'
#' @examples
#'   head(lnc_anno)
"lnc_anno"

#' lnc_annov23
#'
#' annotation for TCGA and gtex expression matrix(lncRNA),form genecode v23 gtf file.
#'
#' @examples
#'   head(lnc_annov23)
"lnc_annov23"

#' mRNA_annov23
#'
#' annotation for TCGA and gtex expression matrix(mRNA),form genecode v23 gtf file.
#'
#' @examples
#'   head(mRNA_annov23)
"mRNA_annov23"

#' mRNA_anno
#'
#' annotation for TCGA and gtex expression matrix(mRNA),form genecode v22 gtf file.
#'
#' @examples
#'   head(mRNA_anno)
"mRNA_anno"

#' meta1
#'
#' clinical messages for some TCGA patients,correspond to exprSet_hub1
#'
#' @examples
#'   head(meta1)
"meta1"

#' pkg_all
#'
#' bioconductor annotation packages for GPLs
#'
#' @examples
#'   head(pkg_all)
"pkg_all"

==> tinyarray_2.3.0.tar.gz: tinyarray/R/data.R <==
#' cod
#'
#' An expression matrix form TCGA
#'
#' @examples
#'   cod
"cod"

#' deg
#'
#' limma differential analysis result for GSE42872
#'
#' @examples
#'   head(deg)
"deg"

#' deseq_data
#'
#' DEseq2 differential analysis result
#'
#' @examples
#'   head(deseq_data)
"deseq_data"

#' exists_anno_list
#'
#' AnnoProbe supported  GPLs
#'
#' @examples
#'   exists_anno_list
"exists_anno_list"

#' exp_hub1
#'
#' An expression matrix from TCGA and Gtex
#'
#' @examples
#'   exp_hub1[1:4,1:4]
"exp_hub1"


#' exprSet_hub1
#'
#' An cpm expression matrix from TCGA,tumor samples only
#'
#' @examples
#'   exprSet_hub1[1:4,1:4]
"exprSet_hub1"


#' genes
#'
#' some gene entriz ids
#'
#' @examples
#'   genes
"genes"

#' lnc_anno
#'
#' annotation for TCGA expression matrix(lncRNA),form genecode v22 gtf file.
#'
#' @examples
#'   head(lnc_anno)
"lnc_anno"

#' lnc_annov23
#'
#' annotation for TCGA and gtex expression matrix(lncRNA),form genecode v23 gtf file.
#'
#' @examples
#'   head(lnc_annov23)
"lnc_annov23"

#' mRNA_annov23
#'
#' annotation for TCGA and gtex expression matrix(mRNA),form genecode v23 gtf file.
#'
#' @examples
#'   head(mRNA_annov23)
"mRNA_annov23"

#' mRNA_anno
#'
#' annotation for TCGA and gtex expression matrix(mRNA),form genecode v22 gtf file.
#'
#' @examples
#'   head(mRNA_anno)
"mRNA_anno"

#' meta1
#'
#' clinical messages for some TCGA patients,correspond to exprSet_hub1
#'
#' @examples
#'   head(meta1)
"meta1"

#' pkg_all
#'
#' bioconductor annotation packages for GPLs
#'
#' @examples
#'   head(pkg_all)
"pkg_all"
